@@ -28,7 +28,7 @@
 #include "actionbar.h"
 #include "annotationwidgets.h"
 #include "core/annotations.h"
-#include "guiutils.h"
+#include "gui/guiutils.h"
 #include "pageview.h"
 #include "pageviewannotator.h"
 #include "settings.h"
@@ -248,7 +248,7 @@ void AnnotationActionHandlerPrivate::parseTool(int toolId)
     // if the opacity value is not a default one, insert a new action in the opacity list
     if (annElement.hasAttribute(QStringLiteral("opacity"))) {
         double opacity = annElement.attribute(QStringLiteral("opacity")).toDouble();
-        aCustomOpacity = selectActionItem(aOpacity, aCustomOpacity, opacity, opacityStandardValues, GuiUtils::createOpacityIcon(opacity), i18nc("@item:inlistbox", "%1\%", opacity * 100));
+        aCustomOpacity = selectActionItem(aOpacity, aCustomOpacity, opacity, opacityStandardValues, GuiUtils::createOpacityIcon(opacity), i18nc("@item:inlistbox", "%1%", opacity * 100));
     } else {
         aOpacity->setCurrentItem(opacityStandardValues.size() - 1); // 100 %
     }
@@ -462,10 +462,11 @@ const QIcon AnnotationActionHandlerPrivate::widthIcon(double width)
 const QIcon AnnotationActionHandlerPrivate::stampIcon(const QString &stampIconName)
 {
     QPixmap stampPix = Okular::AnnotationUtils::loadStamp(stampIconName, 32);
-    if (stampPix.width() == stampPix.height())
+    if (stampPix.width() == stampPix.height()) {
         return QIcon(stampPix);
-    else
+    } else {
         return QIcon::fromTheme(QStringLiteral("tag"));
+    }
 }
 
 void AnnotationActionHandlerPrivate::selectTool(int toolId)
@@ -613,8 +614,9 @@ AnnotationActionHandler::AnnotationActionHandler(PageViewAnnotator *parent, KAct
     for (const auto &ann : tools) {
         // action group workaround: connecting to toggled instead of triggered
         connect(ann, &QAction::toggled, this, [this, toolId](bool checked) {
-            if (checked)
+            if (checked) {
                 d->selectTool(toolId);
+            }
         });
         toolId++;
     }
@@ -634,8 +636,9 @@ AnnotationActionHandler::AnnotationActionHandler(PageViewAnnotator *parent, KAct
         // action group workaround: connecting to toggled instead of triggered
         // (because deselectAllAnnotationActions has to call triggered)
         connect(ann, &QAction::toggled, this, [this, stamp](bool checked) {
-            if (checked)
+            if (checked) {
                 d->slotStampToolSelected(stamp.second);
+            }
         });
     }
     if (!d->aStamp->menu()->actions().isEmpty()) {
@@ -707,7 +710,7 @@ AnnotationActionHandler::AnnotationActionHandler(PageViewAnnotator *parent, KAct
     d->aOpacity = new KSelectAction(QIcon::fromTheme(QStringLiteral("edit-opacity")), i18nc("@action:intoolbar Current annotation config option", "Opacity"), this);
     d->aOpacity->setToolBarMode(KSelectAction::MenuMode);
     for (double opacity : d->opacityStandardValues) {
-        KToggleAction *ann = new KToggleAction(GuiUtils::createOpacityIcon(opacity), QStringLiteral("%1\%").arg(opacity * 100), this);
+        KToggleAction *ann = new KToggleAction(GuiUtils::createOpacityIcon(opacity), QStringLiteral("%1%").arg(opacity * 100), this);
         d->aOpacity->addAction(ann);
         connect(ann, &QAction::triggered, this, [this, opacity]() { d->annotator->setAnnotationOpacity(opacity); });
     }
